# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`dovecot`](#dovecot): This class installs and cofigures dovecot  Parameters:
* [`dovecot::install`](#dovecotinstall): This class installs dovecot packages
* [`dovecot::service`](#dovecotservice): manage dovecot service

### Defined types

* [`dovecot::config`](#dovecotconfig): Internal define to handle configuration content
* [`dovecot::configfile`](#dovecotconfigfile): Internal define to create a configuration file and include it in the main config file

## Classes

### <a name="dovecot"></a>`dovecot`

This class installs and cofigures dovecot

Parameters:

#### Parameters

The following parameters are available in the `dovecot` class:

* [`main_config`](#main_config)
* [`configs`](#configs)
* [`main_config_file`](#main_config_file)
* [`config_path`](#config_path)
* [`local_configdir`](#local_configdir)
* [`owner`](#owner)
* [`group`](#group)
* [`mode`](#mode)
* [`include_sysdefault`](#include_sysdefault)
* [`create_resources`](#create_resources)

##### <a name="main_config"></a>`main_config`

Data type: `Hash`

= {},
Hash of configurations to include in the main
configuration file.
Defaults to {}

Default value: `{}`

##### <a name="configs"></a>`configs`

Data type: `Hash`

Hash of configs to write
Defaults to {}

Default value: `{}`

##### <a name="main_config_file"></a>`main_config_file`

Data type: `String`

the name of the main configuration file

Default value: `'dovecot.conf'`

##### <a name="config_path"></a>`config_path`

Data type: `String`

the path where the configuration is.

Default value: `'/etc/dovecot'`

##### <a name="local_configdir"></a>`local_configdir`

Data type: `String`

the name of a directory to put local
configuration files

Default value: `'conf.d'`

##### <a name="owner"></a>`owner`

Data type: `String`

owner of the configuration files

Default value: `'root'`

##### <a name="group"></a>`group`

Data type: `String`

group of the configuration files

Default value: `'root'`

##### <a name="mode"></a>`mode`

Data type: `String`

mode of the configuration files

Default value: `'0644'`

##### <a name="include_sysdefault"></a>`include_sysdefault`

Data type: `Boolean`

= true,
if true (the default) an include statement
in the main configuration file is added to
include the system defaults before the local
configuration.

Default value: ``true``

##### <a name="create_resources"></a>`create_resources`

Data type: `Hash`

a Hash of Hashes to create additional resources eg. to
retrieve a certificate.
Defaults to {} (do not create any additional resources)
Example (hiera):

dovecot::create_resources:
    sslcert::get_cert:
        get_my_dovecot_cert:
          private_key_path: '/etc/dovecot/ssl/key.pem'
          cert_path: '/etc/dovecot/ssl/cert.pem'

Will result in  executing:

sslcert::get_cert{'get_my_postfix_cert':
  private_key_path => "/etc/dovecot/ssl/key.pem"
  cert_path        => "/etc/dovecot/ssl/cert.pem"
}

Default value: `{}`

### <a name="dovecotinstall"></a>`dovecot::install`

This class installs dovecot packages

#### Parameters

The following parameters are available in the `dovecot::install` class:

* [`packages`](#packages)
* [`package_ensure`](#package_ensure)

##### <a name="packages"></a>`packages`

Data type: `Array`

Array of packages to install

Default value: `['dovecot-core']`

##### <a name="package_ensure"></a>`package_ensure`

Data type: `String`

what to ensure for package
Defaults to 'installed'

Default value: `'installed'`

### <a name="dovecotservice"></a>`dovecot::service`

manage dovecot service

#### Parameters

The following parameters are available in the `dovecot::service` class:

* [`ensure`](#ensure)
* [`enable`](#enable)
* [`service_name`](#service_name)

##### <a name="ensure"></a>`ensure`

Data type: `String`

Whether a service should be running.
Defaults to 'running'

Default value: `'running'`

##### <a name="enable"></a>`enable`

Data type: `Boolean`

Whether a service should be enabled.
Defaults to true

Default value: ``true``

##### <a name="service_name"></a>`service_name`

Data type: `String`

The name of the service

Default value: `'dovecot'`

## Defined types

### <a name="dovecotconfig"></a>`dovecot::config`

Internal define to handle configuration content

#### Parameters

The following parameters are available in the `dovecot::config` defined type:

* [`file`](#file)
* [`recursion`](#recursion)
* [`trim`](#trim)
* [`values`](#values)
* [`sections`](#sections)

##### <a name="file"></a>`file`

Data type: `String`

the name (including path) of the configuration file
Defaults to $title

Default value: `$title`

##### <a name="recursion"></a>`recursion`

Data type: `String`

String to identify the recursion for the sections
For details see code ;(
Defaults to '0'

Default value: `'0'`

##### <a name="trim"></a>`trim`

Data type: `Integer`

integer which gives the amount of spaces used to
ident any configuration added in this iteration of the
recursion. Defauls to 0

Default value: `0`

##### <a name="values"></a>`values`

Data type: `Hash`

Hash of configuration parameters to include in $filename
Defaults to {}
see ::dovecot for more information

Default value: `{}`

##### <a name="sections"></a>`sections`

Data type: `Array[Hash]`

Array of configuration section to include in $filenmame
Defaults to []
see ::dovecot for more information

Default value: `[]`

### <a name="dovecotconfigfile"></a>`dovecot::configfile`

Internal define to create a configuration file
and include it in the main config file

#### Parameters

The following parameters are available in the `dovecot::configfile` defined type:

* [`path`](#path)
* [`owner`](#owner)
* [`group`](#group)
* [`mode`](#mode)
* [`local_configdir`](#local_configdir)
* [`include_in`](#include_in)
* [`filename`](#filename)
* [`values`](#values)
* [`sections`](#sections)

##### <a name="path"></a>`path`

Data type: `String`

path to the configuration file

##### <a name="owner"></a>`owner`

Data type: `String`

owner of the configuration file

##### <a name="group"></a>`group`

Data type: `String`

group of the configuration file

##### <a name="mode"></a>`mode`

Data type: `String`

mode of the configuration file

##### <a name="local_configdir"></a>`local_configdir`

Data type: `String`

directory name where the local configuration is
only used if $include_in is not set to ''

##### <a name="include_in"></a>`include_in`

Data type: `String`

filename to add an include statement for the configuration
file. Defaults to '' which disables this function

Default value: `''`

##### <a name="filename"></a>`filename`

Data type: `String`

the name of the configuration file
Defaults to $title

Default value: `$title`

##### <a name="values"></a>`values`

Data type: `Hash`

Hash of configuration parameters to include in $filename
Defaults to {}
see ::dovecot for more information

Default value: `{}`

##### <a name="sections"></a>`sections`

Data type: `Array[Hash]`

Array of configuration section to include in $filenmame
Defaults to []
see ::dovecot for more information

Default value: `[]`

